pub struct UpdateInvoiceQuery {
pub send_to_recipient: bool,
pub send_to_invoicer: bool,
}Expand description
The update invoice query.
Fields
send_to_recipient: boolIndicates whether to send the invoice update notification to the recipient.
send_to_invoicer: boolIndicates whether to send the invoice update notification to the merchant.