pub enum CaptureStatus {
Completed,
Declined,
PartiallyRefunded,
Pending,
Refunded,
}Expand description
The capture status.
Variants
Completed
The funds for this captured payment were credited to the payee’s PayPal account.
Declined
The funds could not be captured.
PartiallyRefunded
An amount less than this captured payment’s amount was partially refunded to the payer.
Pending
The funds for this captured payment was not yet credited to the payee’s PayPal account. For more information, see status.details.
Refunded
An amount greater than or equal to this captured payment’s amount was refunded to the payer.